/**
 * Corresponds with the box interface returned by methods such as `getBBox`.
 */
interface BoxLike {
    /**
     * The minimum X coordinate of the box.
     */
    x: number;
    /**
     * The minimum Y coordinate of the box.
     */
    y: number;
    width: number;
    height: number;
}
/**
 * Represents an SVG element that can be added to an SVG document (or an overlaid SVG document)
 * to highlight a specified box (such as the bounding box of another SVG element).
 *
 * The underlying DOM nodes that make up a box highlighting are not meant to be directly edited by outside code
 * but rather only edited through the interface provided by this class.
 */
export declare class BoxHighlighting {
    #private;
    /**
     * The actual DOM node that is the box trace.
     *
     * Contains all the elements of the box trace.
     */
    private domNode;
    /**
     * Traces the highlighted box.
     */
    private boxTrace;
    private topLeftCornerBox;
    private topRightCornerBox;
    private bottomRightCornerBox;
    private bottomLeftCornerBox;
    /**
     * The currently highlighted box.
     */
    private highlightedBox;
    constructor();
    private get cornerBoxes();
    /**
     * Appends the box highlighting to the given container node.
     */
    appendTo(container: Node): void;
    /**
     * Removes the box highlighting from any container node that it is in.
     *
     * Has no effect if the box highlighting had no parent container node to begin with.
     */
    remove(): void;
    /**
     * Returns what the path `d` attribute should be for a corner box centered on the given point
     * and taking into account the line thickness of the box highlighting.
     */
    private cornerBoxD;
    /**
     * Repositions and resizes the box highlighting to highlight the specified box.
     */
    highlight(boxLike: BoxLike): void;
    /**
     * Line thickness is specified in pixels.
     *
     * Setting this also affects the sizing of the corner boxes of the box highlighting.
     */
    get lineThickness(): number;
    set lineThickness(lineThickness: number);
    setOpacity(opacity: number): void;
}
export {};
//# sourceMappingURL=BoxHighlighting.d.ts.map